=============
santa-helpers
=============


.. image:: https://img.shields.io/pypi/v/santa_helpers.svg
        :target: https://pypi.python.org/pypi/santa_helpers

.. image:: https://img.shields.io/travis/lenarother/santa_helpers.svg
        :target: https://travis-ci.com/lenarother/santa_helpers

.. image:: https://readthedocs.org/projects/santa-helpers/badge/?version=latest
        :target: https://santa-helpers.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/lenarother/santa_helpers/shield.svg
     :target: https://pyup.io/repos/github/lenarother/santa_helpers/
     :alt: Updates



Helpers for Advent of Codee


* Free software: MIT license
* Documentation: https://santa-helpers.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
